;; Generated package description from go-mode.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "go-mode" "1.6.0.0.20250311.20239" "Major mode for the Go programming language" '((emacs "26.1")) :commit "0ed3c5227e7f622589f1411b4939c3ee34711ebd" :keywords '("languages" "go") :url "https://github.com/dominikh/go-mode.el")
